TextFieldError class abstract

requiredErrorMsg : error message to show when textField is Empty patternErrorMsg : error message to show when TextField reqExp is not match error : general error message

Implementers

Constructors

TextFieldError({String requiredErrorMsg = "", String patternErrorMsg = "", String? error})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
patternErrorMsg String
final
requiredErrorMsg String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited