FormElement class abstract
- Implementers
Constructors
- FormElement({String? id, TypeInput? typeInput, String? initValue = "", String? label = "", String? hint = "", String? error = "", DecorationElement? decorationElement = const UnderlineDecorationElement(), bool? readOnly, bool visibility = true})
Properties
- decorationElement → DecorationElement?
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- id → String?
-
final
- initValue → String?
-
final
- label → String?
-
final
- readOnly → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeInput → TypeInput?
-
final
- visibility → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited